==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SAMLHookResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLHookResponseCommandsInnerValueInner;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLHookResponseCommandsInner
 */
@JsonPropertyOrder({ SAMLHookResponseCommandsInner.JSON_PROPERTY_TYPE,
        SAMLHookResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("SAMLHookResponse_commands_inner")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SAMLHookResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public static final String JSON_PROPERTY_VALUE = "value";
    private List<SAMLHookResponseCommandsInnerValueInner> value = null;

    public SAMLHookResponseCommandsInner() {
    }

    public SAMLHookResponseCommandsInner type(String type) {

        this.type = type;
        return this;
    }

    /**
     * One of the supported commands &#x60;com.okta.assertion.patch&#x60;
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "One of the supported commands `com.okta.assertion.patch`")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    public SAMLHookResponseCommandsInner value(List<SAMLHookResponseCommandsInnerValueInner> value) {

        this.value = value;
        return this;
    }

    public SAMLHookResponseCommandsInner addvalueItem(SAMLHookResponseCommandsInnerValueInner valueItem) {
        if (this.value == null) {
            this.value = new ArrayList<>();
        }
        this.value.add(valueItem);
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SAMLHookResponseCommandsInnerValueInner> getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(List<SAMLHookResponseCommandsInnerValueInner> value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLHookResponseCommandsInner saMLHookResponseCommandsInner = (SAMLHookResponseCommandsInner) o;
        return Objects.equals(this.type, saMLHookResponseCommandsInner.type)
                && Objects.equals(this.value, saMLHookResponseCommandsInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLHookResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SAMLHookResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLHookResponseCommandsInnerValueInner;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLHookResponseCommandsInner
 */
@JsonPropertyOrder({ SAMLHookResponseCommandsInner.JSON_PROPERTY_TYPE,
        SAMLHookResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("SAMLHookResponse_commands_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class SAMLHookResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public static final String JSON_PROPERTY_VALUE = "value";
    private List<SAMLHookResponseCommandsInnerValueInner> value = null;

    public SAMLHookResponseCommandsInner() {
    }

    public SAMLHookResponseCommandsInner type(String type) {

        this.type = type;
        return this;
    }

    /**
     * One of the supported commands &#x60;com.okta.assertion.patch&#x60;
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "One of the supported commands `com.okta.assertion.patch`")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    public SAMLHookResponseCommandsInner value(List<SAMLHookResponseCommandsInnerValueInner> value) {

        this.value = value;
        return this;
    }

    public SAMLHookResponseCommandsInner addvalueItem(SAMLHookResponseCommandsInnerValueInner valueItem) {
        if (this.value == null) {
            this.value = new ArrayList<>();
        }
        this.value.add(valueItem);
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SAMLHookResponseCommandsInnerValueInner> getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(List<SAMLHookResponseCommandsInnerValueInner> value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLHookResponseCommandsInner saMLHookResponseCommandsInner = (SAMLHookResponseCommandsInner) o;
        return Objects.equals(this.type, saMLHookResponseCommandsInner.type)
                && Objects.equals(this.value, saMLHookResponseCommandsInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLHookResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
